@@ -3,7 +3,7 @@ BEGIN {
   $Bread::Board::Declare::Meta::Role::Attribute::Container::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Bread::Board::Declare::Meta::Role::Attribute::Container::VERSION = '0.14';
+  $Bread::Board::Declare::Meta::Role::Attribute::Container::VERSION = '0.15';
 }
 use Moose::Role;
 Moose::Util::meta_attribute_alias('Container');
@@ -91,7 +91,7 @@ Bread::Board::Declare::Meta::Role::Attribute::Container - attribute metarole for
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 DESCRIPTION
 
@@ -131,13 +131,14 @@ the dependency specification to use for that temporary service.
 
 =head1 AUTHOR
 
-Jesse Luehrs <doy at tozt dot net>
+Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Jesse Luehrs.
+This software is Copyright (c) 2013 by Jesse Luehrs.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =cut
