@@ -3,14 +3,13 @@ BEGIN {
   $Bread::Board::Declare::Meta::Role::Class::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Bread::Board::Declare::Meta::Role::Class::VERSION = '0.14';
+  $Bread::Board::Declare::Meta::Role::Class::VERSION = '0.15';
 }
 use Moose::Role;
 # ABSTRACT: class metarole for Bread::Board::Declare
 
 use Bread::Board::Service;
 use Class::Load qw(load_class);
-use List::MoreUtils qw(any);
 
 
 
@@ -52,7 +51,7 @@ Bread::Board::Declare::Meta::Role::Class - class metarole for Bread::Board::Decl
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 DESCRIPTION
 
@@ -67,13 +66,14 @@ Returns all of the services that are associated with attributes in this class.
 
 =head1 AUTHOR
 
-Jesse Luehrs <doy at tozt dot net>
+Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Jesse Luehrs.
+This software is Copyright (c) 2013 by Jesse Luehrs.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =cut
