@@ -3,7 +3,7 @@ BEGIN {
   $Bread::Board::Declare::Role::Service::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Bread::Board::Declare::Role::Service::VERSION = '0.14';
+  $Bread::Board::Declare::Role::Service::VERSION = '0.15';
 }
 use Moose::Role;
 # ABSTRACT: role for Bread::Board::Service objects
@@ -69,7 +69,7 @@ Bread::Board::Declare::Role::Service - role for Bread::Board::Service objects
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 DESCRIPTION
 
@@ -93,13 +93,14 @@ contained in.
 
 =head1 AUTHOR
 
-Jesse Luehrs <doy at tozt dot net>
+Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Jesse Luehrs.
+This software is Copyright (c) 2013 by Jesse Luehrs.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =cut
